@@ -20,7 +20,7 @@ class ProcessorService(processor_pb2_grpc.ProcessorServicer):
             pass
         for item in self.flow_manager.run(flow_name, data):
             yield processor_pb2.FlowResponse(
-                jsonString=json.dumps(item, default=grebble_converter), streamEnd=False
+                data=json.dumps(item, default=grebble_converter), streamEnd=False
             )
 
-        yield processor_pb2.FlowResponse(jsonString="", streamEnd=True)
+        yield processor_pb2.FlowResponse(data=None, streamEnd=True)
